@@ -1,11 +1,11 @@
 # Get Data
 # It takes data as dataframe (edges) or as matrix (table) to be exported in proper form to be used by the diversity function.
 # data Data to be processed as dataframe or as matrix. 
-# entity_col TRUE if column analysis is needed.
-get_data <- function(data, entity_col=FALSE)
+# category_row TRUE if column analysis is needed.
+get_data <- function(data, category_row=FALSE)
 {
 	if (is.data.frame(data)) {
-		if(entity_col==TRUE) {
+		if(category_row==TRUE) {
 			#diversity <- data.frame(row.names=levels(data[,2]))
 			data <- droplevels(data) #delete un used levels
 			X <- matrix(0, nrow=nlevels(data[,2]), ncol=nlevels(data[,1]), dimnames=list(levels(data[,2]),levels(data[,1])))
@@ -18,7 +18,7 @@ get_data <- function(data, entity_col=FALSE)
 		}
 	}
 	else {
-		if (entity_col==TRUE) {
+		if (category_row==TRUE) {
 			X <- t(data)
 			#diversity <- data.frame(row.names=rownames(X))
 		}
